<?php

namespace Drupal\nodeviewcount\Tests;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Tests settings form of nodeviewcount module.
 *
 * @group nodeviewcount
 */
class NodeViewCountSettingsFormTest extends NodeViewCountTestBase {

  use StringTranslationTrait;

  /**
   * Tests that default settings displayed right on the form.
   */
  public function testDefaultSettings() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/config/content/nodeviewcount');

    $this->assertSession()->checkboxChecked('edit-node-types-tracked-page');
    $this->assertSession()->checkboxNotChecked('edit-node-types-not-tracked-page');
    $this->assertSession()->checkboxChecked('edit-view-modes-full');
    $this->assertSession()->checkboxChecked('edit-view-modes-teaser');
    $this->assertSession()->checkboxChecked('edit-user-roles-anonymous');
    $this->assertSession()->checkboxChecked('edit-user-roles-logged');
    $this->assertSession()->checkboxNotChecked('edit-user-roles-authenticated');
    $this->assertSession()->fieldNotExists('edit-user-roles-administrator');
    $this->assertSession()->fieldNotExists('edit-excluded-user-roles-anonymous');
    $this->assertSession()->fieldNotExists('edit-excluded-user-roles-logged');
    $this->assertSession()->checkboxNotChecked('edit-excluded-user-roles-authenticated');
    $this->assertSession()->checkboxChecked('edit-excluded-user-roles-administrator');
    $this->assertSession()->optionExists('edit-logs-life-time', 0);

    $this->drupalLogout();
  }

  /**
   * Tests that settings are changed on form submit.
   */
  public function testEditingSettings() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/config/content/nodeviewcount');

    $edit = [
      'logs_life_time' => 604800,
      'user_roles[authenticated]' => TRUE,
    ];
    $this->submitForm($edit, $this->t('Save configuration'));
    $this->assertSession()->checkboxChecked('edit-user-roles-authenticated');
    $this->assertSession()->fieldNotExists('edit-excluded-user-roles-authenticated');
    $this->assertSession()->optionExists('edit-logs-life-time', 604800);

    $this->drupalLogout();
  }

}
